VERSION 8000; ; 8300
* -----------------------------------------------------------------------------
* @filedoc
* @file Punkte_AusBlattschnitten.CSX
* @brief Blattschnittkoordinaten als Punkte speichern
* 
* Dieses Beispielskript ermittelt die Eckkoordinaten aller Blattschnitte.
* Die Eckkoordinaten werden als Punkte der CARD/1 Punktdatenbank gespeichert.
* Zur Kontrolle wird das Ergebnis in der Lageansicht visualisiert.
* Zustzlich werden zu den Punkten Nebenattribute erfasst.
*
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author JH
* @endfiledoc
* -----------------------------------------------------------------------------
* @history
* -----------------------------------------------------------------------------


* Vereinbarungen --------------------------------------------------------------

BILDSCHIRM GRAFIK                       | Meldungen im Arbeitsprotokoll ausgeben


* Implizite Deklarationen -----------------------------------------------------

LfdNr = 1
!PN_Konst = "BL."                       | Nummernkonstante fr Punkte (Prfix)
!P_Bemerk = "Blattecke"                 | Bemerkungstext fr Punkte
PKode = 9999                            | Kode fr Punkte


* Explizite Deklarationen -----------------------------------------------------

SYMBOLE * !Blattname                    | Symbol fr Blattname
SYMBOLE * WRrad; M; B; H                | Symbole fr Blattattribute
SYMBOLE * BBreite; BHoehe               | Symbole fr Blattabmessungen

* Symbole fr Systemobjekte
SYMBOLE /POINTSYS/ PointSys
SYMBOLE /SHEETSYS/ SheetSys

* Symbole fr Punkt- und Blattschnittobjekte
SYMBOLE /POINT/ Point
SYMBOLE /SHEET/ Sheet

* Symbole fr Hilfsobjekte
SYMBOLE /LINE/ Line1; Line2
SYMBOLE /COORDINATE/ Koor1; Koor2

                
* Ausfhrungen ----------------------------------------------------------------

* Systemobjekte
Pointsys = Project.GetPointSys()
SheetSys = Project.GetSheetSys()

*** Schleife zum fortlaufenden Auslesen der Blattschnitte

* Blattschnittobjekt
Sheet = $NULL
SOLANGE Sheet = SheetSys.GetNextSheet(Sheet)
  
  * Blattattribute 
  !BlattName = Sheet.GetName()                 | Blattname
    TV = T_GLEICH(!BlattName; "$LAGE")
    WENN TV == 1 DANN NCHSTE SOLANGE
  BezugX = Sheet.GetLeftLowerCornerX()         | Koordinate des Bezugspunktes
  BezugY = Sheet.GetLeftLowerCornerY()         |
  WRad = Sheet.GetAngle()                      | Winkel [rad]
  B = Sheet.GetExtentWidth()                   | Blattbreite [cm]
  H = Sheet.GetExtentHeight()                  | Blatthhe [cm]
  M = Sheet.GetMeasure()                       | Blattmastab
  
  * Blattabmessungen 1:1 
  BBreite = B*M / 100
  BHoehe = H*M / 100

  *** Ermittlung des unteren Blattrandes
  
  * Hilfsobjekte 
  Line1.SetPosition(BezugX; BezugY)            | setzt den Anfangspunkt der Hilfslinie (= Blattecke links unten)
  Line1.SetAngle(WRad)                         | setzt die Richtung der Hilfslinie
  Line1.SetDistance(BBreite)                   | setzt die Lnge der Hilfslinie (= Blattecke rechts unten)
  Koor1 = Line1.GetCoordinate()                | liefert die Koordinate des Anfangspunktes
  Koor2 = Line1.GetLateralPoint(BBreite)       | liefert die Koordinate des Endpunktes
  
  Line1.Draw(7)                                | visualisiert die Hilfsobjekte
  Koor1.Draw(7)
  Koor2.Draw(7)

  * Funktionsaufruf: Ermittlung freier Punktnummer
  !Pkt_Name = !FreiePktNr(!PN_Konst; LfdNr)
  
  * Punktobjekt: Blattecke links unten 
  Point = PointSys.CreatePoint(!Pkt_Name)
  Point.SetCoordinate(Koor1)
  Point.SetCode(PKode)
  Point.SetRemark(!P_Bemerk)
  Point.SetAttribute( "Blatt"; !BlattName)
  Point.SetAttribute( "Position"; "Blattecke links unten")

  * Funktionsaufruf: Ermittlung freier Punktnummer
  !PKT_Name = !FreiePktNr(!PN_Konst; LfdNr)
  
  * Punktobjekt: Blattecke rechts unten
  Point = PointSys.CreatePoint(!Pkt_Name)
  Point.SetCoordinate(Koor2)
  Point.SetCode(PKode)
  Point.SetRemark(!P_Bemerk)
  Point.SetAttribute("Blatt"; !BlattName)
  Point.SetAttribute("Position"; "Blattecke rechts unten")

  *** Ermittlung des oberen Blattrandes
  
  * Hilfsobjekte
  Line2 = Line1.GetParallelLine(-BHoehe)       | liefert eine parallele Linie zur Linie "Line1"
  Koor1 = Line2.GetCoordinate()                | liefert die Koordinate des Anfangspunktes (= Blattecke links oben)
  Koor2 = Line2.GetLateralPoint(BBreite)       | liefert die Koordinate des Endpunktes (= Blattecke rechts oben)
  
  Line2.Draw(7)                                | visualisiert die Hilfsobjekte
  Koor1.Draw(7)
  Koor2.Draw(7)

  * Funktionsaufruf: Ermittlung freier Punktnummer
  !PKT_Name = !FreiePktNr(!PN_Konst;LfdNr)
  
  * Punktobjekt: Blattecke links oben
  Point = PointSys.CreatePoint(!Pkt_Name)
  Point.SetCoordinate(Koor1)
  Point.SetCode(PKode)
  Point.SetRemark(!P_Bemerk)
  Point.SetAttribute( "Blatt"; !BlattName)
  Point.SetAttribute( "Position"; "Blattecke links oben")

  * Funktionsaufruf: Ermittlung freier Punktnummer
  !PKT_Name = !FreiePktNr(!PN_Konst;LfdNr)
  
  * Punktobjekt: Blattecke rechts oben
  Point = PointSys.CreatePoint(!Pkt_Name)
  Point.SetCoordinate(Koor2)
  Point.SetCode(PKode)
  Point.SetRemark(!P_Bemerk)
  Point.SetAttribute( "Blatt"; !BlattName)
  Point.SetAttribute( "Position"; "Blattecke rechts oben")
  
  
MELDE " Blatt # M=# B=#.### H=#.### W=#.#####"; !Blattname; M; B; H; WRad
  
ENDE SOLANGE

*** Ende Schleife

STOP


* -----------------------------------------------------------------------------
* @function FreiePktNr
* @brief Funktion zum Suchen der nchsten freien Punktnummer einer Basis
* @param !Praefix: Nummernbasis
* @param LfdNr: laufende Nummer, die hochgezhlt wird 
*
* @return !NeueNr: Nchste freie Punktnummer, die verwendet werden kann
*
* @ingroup
* @author JH
* @endfunction

FUNKTION !FreiePktNr: !Praefix; LfdNr

  SYMBOLE /POINT/ XPoint
  SYMBOLE * !NeueNr
  
  TEXTGEN !LfdNr; "#"; LfdNr
  !NeueNr = !Praefix + !LfdNr

  * nchste freie Punktnummer suchen
  SOLANGE XPoint = PointSys.GetPoint(!NeueNr)
    LfdNr = LfdNr + 1
    TEXTGEN !LfdNr; "#"; LfdNr
    !NeueNr = !Praefix + !LfdNr
  ENDE SOLANGE
  
  ZURCK !NeueNr 
  
ENDE FUNKTION
